@@ -49,6 +49,7 @@ def get_argument_parser():
     parser.add_argument('--sdkgen_release', metavar='sdkgen-release', help='Release of SDK generator to download')
     parser.add_argument('--commit_msg', metavar='commit-message',
                         help='Custom commit message for pushing to apidocs repo')
+    parser.add_argument('--skip_sdkgen', action='store_true', help='Do not run sdkgen to generate SDK-specific files')
     parser.add_argument('--push', action='store_true', help='Push updated apidocs repos to GHE after generating')
     parser.add_argument('--keep_sdk', action='store_true', help='Keep generated SDK files')
     parser.add_argument('--keep_temp', action='store_true', help='Keep temp directory')
@@ -124,7 +125,10 @@ def main():
         mapping = None
     sdk_versions = {}
     frontmatter_cli = get_frontmatter_cli(args.frontmatter, temp_dir)
-    sdk_generator_cli = get_sdk_generator_cli(args.sdk_generator, args.sdkgen_release, mapping, temp_dir)
+    if not args.skip_sdkgen:
+        sdk_generator_cli = get_sdk_generator_cli(args.sdk_generator, args.sdkgen_release, mapping, temp_dir)
+    else:
+        sdk_generator_cli = None
 
     for openapi in args.openapi:
 
@@ -197,7 +201,8 @@ def main():
                              output_frontmatter_config=output_frontmatter_config,
                              example_files=example_files, sdk_versions=sdk_versions,
                              no_update=args.no_update, frontmatter_md_file=frontmatter_md_file,
-                             keep_sdk=args.keep_sdk, push=args.push, commit_msg=args.commit_msg)
+                             keep_sdk=args.keep_sdk, skip_sdkgen=args.skip_sdkgen,
+                             push=args.push, commit_msg=args.commit_msg)
 
     if not args.keep_temp:
         logger.info('Removing temporary directory %s', temp_dir)
@@ -207,7 +212,7 @@ def process_openapi_file(openapi_file=None, frontmatter_cli=None, sdk_generator_
                          examples_dir=None, output_folder=None, apidocs_dir=None, service_name=None,
                          input_frontmatter_config=None, output_frontmatter_config=None, example_files=None,
                          sdk_versions=None, no_update=None, frontmatter_md_file=None, keep_sdk=None,
-                         push=None, commit_msg=None):
+                         skip_sdkgen=None, push=None, commit_msg=None):
 
     supported_languages = get_supported_languages(openapi_file)
 
@@ -239,10 +244,13 @@ def process_openapi_file(openapi_file=None, frontmatter_cli=None, sdk_generator_
                                frontmatter_config_file=output_frontmatter_config, output_file=frontmatter_md_file,
                                templates_dir=templates_dir)
 
-    logger.info('Creating language specific middle panel')
-    create_language_specific_files(sdk_generator_cli=sdk_generator_cli, supported_languages=supported_languages,
-                                   openapi_file=openapi_file, apidocs_folder=apidocs_dir, output_folder=output_folder,
-                                   keep_sdk=keep_sdk)
+    if not skip_sdkgen:
+        logger.info('Running sdkgen to creating language-specific JSON files')
+        create_language_specific_files(sdk_generator_cli=sdk_generator_cli, supported_languages=supported_languages,
+                                       openapi_file=openapi_file, apidocs_folder=apidocs_dir, output_folder=output_folder,
+                                       keep_sdk=keep_sdk)
+    else:
+        logger.info('Skipping sdkgen')
 
     if push:
         logger.info('Pushing updated files from %s to cloud-api-docs/%s', apidocs_dir, service_name)
